==> weld-spi-3.1.SP3-sources.jar: org/jboss/weld/injection/spi/helpers/ForwardingResourceInjectionServices.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.injection.spi.helpers;

import javax.enterprise.inject.spi.InjectionPoint;

import org.jboss.weld.injection.spi.ResourceReferenceFactory;
import org.jboss.weld.injection.spi.ResourceInjectionServices;

public abstract class ForwardingResourceInjectionServices implements ResourceInjectionServices {

    protected abstract ResourceInjectionServices delegate();

    public ResourceReferenceFactory<Object> registerResourceInjectionPoint(InjectionPoint injectionPoint) {
        return delegate().registerResourceInjectionPoint(injectionPoint);
    }

    public ResourceReferenceFactory<Object> registerResourceInjectionPoint(String jndiName, String mappedName) {
        return delegate().registerResourceInjectionPoint(jndiName, mappedName);
    }
}

==> weld-spi-5.0.SP3-sources.jar: org/jboss/weld/injection/spi/helpers/ForwardingResourceInjectionServices.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.injection.spi.helpers;

import jakarta.enterprise.inject.spi.InjectionPoint;

import org.jboss.weld.injection.spi.ResourceReferenceFactory;
import org.jboss.weld.injection.spi.ResourceInjectionServices;

public abstract class ForwardingResourceInjectionServices implements ResourceInjectionServices {

    protected abstract ResourceInjectionServices delegate();

    public ResourceReferenceFactory<Object> registerResourceInjectionPoint(InjectionPoint injectionPoint) {
        return delegate().registerResourceInjectionPoint(injectionPoint);
    }

    public ResourceReferenceFactory<Object> registerResourceInjectionPoint(String jndiName, String mappedName) {
        return delegate().registerResourceInjectionPoint(jndiName, mappedName);
    }
}
